Crate cli_battery_pack

Crate cli_battery_pack 

cli-battery-pack

A battery pack for building CLI applications in Rust.

What’s Included

CrateWhat it does
anyhowErgonomic error handling for applications
clapCommand-line argument parsing with derive macros
dialoguerInteractive prompts and user input

Optional features

  • indicatorsindicatif for progress bars, console for terminal styling
  • searchregex for pattern matching, ignore for gitignore-aware file walking

Quick Start

cargo bp add cli

Want progress bars too?

cargo bp add cli -F indicators

License

Licensed under either of:

at your option.

CrateVersionDescription
anyhow1Flexible concrete Error type built on std::error::Error
battery-pack0.4Curated crate bundles with docs, templates, and agentic skills
clap4A simple to use, efficient, and full-featured Command Line Argument Parser
console0.15A terminal and console abstraction for Rust
dialoguer0.11A command line prompting library.
ignore0.4A fast library for efficiently matching ignore files such as .gitignore
against file paths.

| | indicatif | 0.17 | A progress bar and cli reporting library for Rust | | regex | 1 | An implementation of regular expressions for Rust. This implementation uses finite automata and guarantees linear time matching on all inputs. |