cli-battery-pack
A battery pack for building CLI applications in Rust.
What’s Included
| Crate | What it does |
|---|---|
| anyhow | Ergonomic error handling for applications |
| clap | Command-line argument parsing with derive macros |
| dialoguer | Interactive prompts and user input |
Optional features
- indicators —
indicatiffor progress bars,consolefor terminal styling - search —
regexfor pattern matching,ignorefor gitignore-aware file walking
Quick Start
cargo bp add cliWant progress bars too?
cargo bp add cli -F indicatorsLicense
Licensed under either of:
- Apache License, Version 2.0 (LICENSE-APACHE or http://www.apache.org/licenses/LICENSE-2.0)
- MIT license (LICENSE-MIT or http://opensource.org/licenses/MIT)
at your option.
| Crate | Version | Description |
|---|---|---|
| anyhow | 1 | Flexible concrete Error type built on std::error::Error |
| battery-pack | 0.4 | Curated crate bundles with docs, templates, and agentic skills |
| clap | 4 | A simple to use, efficient, and full-featured Command Line Argument Parser |
| console | 0.15 | A terminal and console abstraction for Rust |
| dialoguer | 0.11 | A command line prompting library. |
| ignore | 0.4 | A fast library for efficiently matching ignore files such as .gitignore |
| against file paths. |
| | indicatif | 0.17 | A progress bar and cli reporting library for Rust | | regex | 1 | An implementation of regular expressions for Rust. This implementation uses finite automata and guarantees linear time matching on all inputs. |